function samp = rejection_sampler(x,y, n)
% Input: Set of points representing the hand-drawn density curve, sample size n 
% Output: A sample of size n from the population hand-drawn by the user

samp =[];       % Vector holding the final sample

%Given the x and y coordinates of the density curve
n_x = length(x);            
range_x = x(n_x) - x(1);
max_y = max(y);

while (length(samp)<n)          % While our sample is not complete ...
    r1 = x(1) + range_x*rand(); % Generate the x-coordinate
    r2 = max_y*rand();          % Generate the y-coordinate
    loc = find(x>r1,1);         % Find the proper place on the density curve
    
    % Height of the density curve at the x-coordinate
    bound = y(loc-1) + (y(loc)-y(loc-1))/(x(loc)-x(loc-1))*(r1-x(loc-1));
        
    % If our sampled point is below the density curve, we 'accept' this sample
    if(r2<bound)
        samp = [samp; r1];
    end
    
end


%{
% If you want to view a particular rejection sample akin to Figure 2 in the
% manuscript, use the while loop below instead of the one from above

count = 0;              % Keeps track of total number of sampled values

while (length(samp)<n)  % While our sample is not complete ...
    
    count = count+1;
    r1(count) = x(1) + range_x*rand();  % Generate the x-coordinate
    r2(count) = max_y*rand();           % Generate the y-coordinate
    loc = find(x>r1(count),1);          % Find the proper place on the density curve
    
    % Height of the density curve at the x-coordinate
    bound = y(loc-1) + (y(loc)-y(loc-1))/(x(loc)-x(loc-1))*(r1(count)-x(loc-1));
    
    % If our sampled point is below the density curve, we 'accept' this sample
    if(r2(count)<bound)
        samp = [samp; r1(count)];
        ID(count) = 1;
    else            % Else we 'reject the sampled point
        ID(count) = 2;
    end
    
end


figure(8);
plot(x,y);      % Plots the density curve
hold;
scatter(r1(ID ==1),r2(ID ==1), 60, 'g*', 'linewidth', 2);
scatter(r1(ID ==2),r2(ID ==2), 60, 'rx', 'linewidth', 2);
hold
%}

end